@@ -29,9 +29,17 @@
 #endif
 
 #ifndef Q_MOC_RUN
+#  define INJEQT_INIT
+#  define INJEQT_DONE
+#  define INJEQT_SET
+// depreceated, use INJEQT_SET instead
 #  define INJEQT_SETTER
 #endif
 
-namespace injeqt { namespace v1 { }
-using namespace v1;
+#define INJEQT_TYPE_ROLE_CLASSINFO_NAME "injeqt.type-role"
+#define INJEQT_TYPE_ROLE(N) Q_CLASSINFO(INJEQT_TYPE_ROLE_CLASSINFO_NAME, N)
+
+namespace injeqt {
+	namespace v1 { }
+	using namespace v1;
 }
